const apiBaseUrl = "https://api.hyperapps.in/api/v2";

// State Management for Tabs
const tabState = {
  all: { currentPage: 0, isLoading: false, noMoreOrders: false },
  live: { currentPage: 0, isLoading: false, noMoreOrders: false },
  past: { currentPage: 0, isLoading: false, noMoreOrders: false },
};

let currentTab = 'live'; // Default to 'live' tab

// DOM Elements
const ordersTableBody = document.getElementById("ordersTableBody");
const loadingIndicator = document.getElementById("loadingIndicator");
const searchBtn = document.getElementById("searchBtn");
const statusFilter = document.getElementById("statusFilter");
const searchCustomer = document.getElementById("searchCustomer");
const noMoreOrdersMessage = document.getElementById("noMoreOrdersMessage");
const filterContainer = document.getElementById("filterContainer");

// Tab Buttons
const allOrdersTab = document.getElementById("allOrdersTab");
const liveOrdersTab = document.getElementById("liveOrdersTab");
const pastOrdersTab = document.getElementById("pastOrdersTab");

// Tab Event Listeners
liveOrdersTab.addEventListener("click", () => switchTab('live'));
pastOrdersTab.addEventListener("click", () => switchTab('past'));
allOrdersTab.addEventListener("click", () => switchTab('all'));

// Search Event Listener (Only for All Orders Tab)
searchBtn.addEventListener("click", () => {
  if (currentTab === 'all') {
    resetTabState('all');
    ordersTableBody.innerHTML = ""; // Clear table content
    noMoreOrdersMessage.style.display = "none";
    fetchOrders(); // Trigger fetch with filters applied
  }
});

const orderIdSearchInput = document.getElementById('orderIdSearch');
const orderIdSearchButton = document.getElementById('orderIdSearchButton');

orderIdSearchButton.addEventListener('click', () => {
    const orderId = orderIdSearchInput.value.trim();
    if (orderId) {
        window.location.href = `order-details.html?orderId=${orderId}`;
    } else {
        alert("Please enter an Order ID.");
    }
});

// Scroll Event Listener for Pagination
window.addEventListener("scroll", () => {
  const state = tabState[currentTab];
  if (state.isLoading || state.noMoreOrders) return;
  if (window.innerHeight + window.scrollY >= document.body.offsetHeight - 100) {
    fetchOrders();
  }
});

// Tab Switching Logic
function switchTab(tab) {
  currentTab = tab;
  resetTabState(tab);


  liveOrdersTab.classList.toggle("active", tab === 'live');
  pastOrdersTab.classList.toggle("active", tab === 'past');
  allOrdersTab.classList.toggle("active", tab === 'all');


  if (currentTab === 'all') {
      filterContainer.style.display = 'flex';  // Show for 'all' tab
      searchBtn.style.display = 'block';      // Show for 'all' tab
      searchCustomer.style.display = 'block'; // Show for 'all' tab
      statusFilter.style.display = 'block';    // Show for 'all' tab

  } else {
      filterContainer.style.display = 'none';   // Hide for other tabs
      searchBtn.style.display = 'none';       // Hide for other tabs
      searchCustomer.style.display = 'none';  // Hide for other tabs
      statusFilter.style.display = 'none';     // Hide for other tabs
  }


  ordersTableBody.innerHTML = "";
  noMoreOrdersMessage.style.display = "none";

  fetchOrders();
}

// Reset Tab State
function resetTabState(tab) {
  tabState[tab].currentPage = 0;
  tabState[tab].isLoading = false;
  tabState[tab].noMoreOrders = false;
}



function getStatusStyles(status) {
  switch (status) {
    case 'CREATED':
      return { backgroundColor: 'orange', textColor: 'white' };
    case 'PAYMENT_PENDING':
      return { backgroundColor: 'yellow', textColor: 'black' }; // Golden yellow with black text
    case 'PAID':
      return { backgroundColor: 'green', textColor: 'white' };
    case 'DELIVERED':
      return { backgroundColor: 'blue', textColor: 'white' };
    default:
      return { backgroundColor: 'grey', textColor: 'white' };
  }
}

// Fetch Orders
async function fetchOrders() {
  const state = tabState[currentTab];
  if (state.isLoading || state.noMoreOrders) return;

  state.isLoading = true;
  loadingIndicator.style.display = "block";

  const customerId = searchCustomer.value.trim();
  const status = statusFilter.value;

  const params = new URLSearchParams({
    limit: '15',
    offset: state.currentPage.toString(),
  });

  if (currentTab === 'all') {
    if (customerId) params.append("customerId_eq", customerId);
    if (status) params.append("status_eq", status);
  } else if (currentTab === 'live') {
    params.append("status_nin", "CANCELLED,DELIVERED");
  } else if (currentTab === 'past') {
    params.append("status_in", "CANCELLED,DELIVERED");
  }

  try {
    const response = await fetch(`${apiBaseUrl}/order?${params}`);
    if (response.ok) {
      const data = await response.json();
      const orders = data.data;

      if (orders.length < 15) {
        state.noMoreOrders = true;
        noMoreOrdersMessage.style.display = "block";
      }

      orders.forEach(order => {
        const { backgroundColor, textColor } = getStatusStyles(order.status);

        const row = document.createElement("tr");

        // Making Order ID clickable and redirecting to order-details.html with the orderId in the URL
        row.innerHTML = `
        <td><a href="order-details.html?orderId=${order.id}" class="text-decoration-none text-primary">${order.id}</a></td>
        <td>
          <span class="badge" style="background-color: ${backgroundColor}; color: ${textColor}; padding: 5px 8px; font-size: 0.9em; border-radius: 4px;">
            ${order.status}
          </span>
        </td>
        <td>${order.restaurantId}</td>
        <td>${order.customerId}</td>
        <td>
          ${formatDate(order.createdAt)} <br> 
          ${formatDate(order.updatedAt)}
        </td>
        <td>${order.orderItems.length}</td>
        <td>₹${order.grandTotalAmount}</td>
        <td>
          ${order.status === 'CREATED' || order.status === 'PAYMENT_PENDING' ? `
            <button class="btn btn-sm" style="background-color: blue; color: white;" 
              onclick="markAsDelivered('${order.id}')">
              Mark as Delivered
            </button>
          ` : ''}
          
          ${order.status === 'CREATED' || order.status === 'PAYMENT_PENDING' ? `
            <button class="btn btn-sm" style="background-color: red; color: white;" 
              onclick="cancelOrder('${order.id}')">
              Cancel Order
            </button>
          ` : ''}
          
          ${order.status === 'CREATED' || order.status === 'PAYMENT_PENDING' ? `
            <button class="btn btn-sm" style="background-color: orange; color: white;" 
              onclick="allocateOrder('${order.id}')">
              Allocate Order
            </button>
          ` : ''}
        </td>
      `;
        ordersTableBody.appendChild(row);
      });

      state.currentPage++;
    }
  } catch (error) {
    console.error("Error fetching orders:", error);
  } finally {
    state.isLoading = false;
    loadingIndicator.style.display = "none";
  }
}

// Action Functions
function markAsDelivered(orderId) {
  const modal = new bootstrap.Modal(document.getElementById('confirmDeliveryModal'));
  const confirmButton = document.getElementById('confirmMarkAsDeliveredBtn');

  confirmButton.onclick = () => {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "DELIVERED",
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order marked as delivered.");
        fetchOrders(); // Refresh the orders table
      })
      .catch(error => console.error("Error marking order as delivered:", error));

    modal.hide(); // Close the modal
  };

  modal.show(); // Show the modal
}

function cancelOrder(orderId) {
  if (confirm("Are you sure you want to cancel this order?")) {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "CANCELLED", // Change status to CANCELLED
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order cancelled successfully.");
        fetchOrders(); // Refresh the orders table
      })
      .catch(error => console.error("Error cancelling order:", error));
  }
}

function allocateOrder(orderId) {
  if (confirm("Are you sure you want to allocate this order?")) {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "ALLOCATED", // Change status to ALLOCATED (or whatever status you use for allocated orders)
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order allocated successfully.");
        fetchOrders(); // Refresh the orders table
      })
      .catch(error => console.error("Error allocating order:", error));
  }
}


// Initial Fetch (Load Live Orders Tab by default)
switchTab('live');